<?php

/*************************************************
## Register Store Taxonomy
*************************************************/ 

function custom_taxonomy_store()  {
$labels = array(
    'name'                       => 'Stores',
    'singular_name'              => 'Store',
    'menu_name'                  => 'Stores',
    'all_items'                  => 'All Stores',
    'parent_item'                => 'Parent Item',
    'parent_item_colon'          => 'Parent Item:',
    'new_item_name'              => 'New Item Name',
    'add_new_item'               => 'Add New Store',
    'edit_item'                  => 'Edit Item',
    'update_item'                => 'Update Item',
    'separate_items_with_commas' => 'Separate Item with commas',
    'search_items'               => 'Search Items',
    'add_or_remove_items'        => 'Add or remove Items',
    'choose_from_most_used'      => 'Choose from the most used Items',
);
$args = array(
    'labels'                     => $labels,
    'hierarchical'               => true,
    'public'                     => true,
    'show_ui'                    => true,
    'show_admin_column'          => true,
    'show_in_nav_menus'          => true,
    'show_tagcloud'              => true,
);
register_taxonomy( 'store', array( 'product','shop_coupon' ), $args );
register_taxonomy_for_object_type( 'store', array( 'product','shop_coupon' ) );
}
add_action( 'init', 'custom_taxonomy_store' );



/*************************************************
## Add  New Field to the Store Taxonomy Page
*************************************************/ 

add_action( 'category_add_form_fields', 'froday_taxonomy_add_new_meta_field', 10, 2 );
function froday_taxonomy_add_new_meta_field() {
    ?>
		<?php wp_enqueue_media(); ?>

    <div class="form-field">
        <label for="term_meta[store_thumbnail]"><?php esc_html_e( 'Thumbnail', 'froday' ); ?></label>
		
		<div class="image-preview-wrapper">
			<img id="image-preview" src="<?php echo get_template_directory_uri(); ?>/assets/images/placeholder.png" height="100">
		</div>
			<input id="upload_image_button" type="button" class="button" value="<?php esc_html_e( 'Upload image','froday' ); ?>" />
			<input type='hidden' name='term_meta[store_thumbnail]' id='image_attachment_id' value='<?php echo esc_attr( $term_meta['store_thumbnail'] ) ? esc_attr( $term_meta['store_thumbnail'] ) : ''; ?>'>
		
	</div>
<?php
}
// Add fields on custom taxonomies
add_action( 'store_add_form_fields', 'froday_taxonomy_add_new_meta_field');


/*************************************************
## Add  New Field to the Store Edit Taxonomy Page
*************************************************/ 

add_action( 'category_edit_form_fields', 'froday_taxonomy_edit_meta_field', 10, 2 );
function froday_taxonomy_edit_meta_field($term) {
 
    // put the term ID into a variable
    $t_id = $term->term_id;
 
    // retrieve the existing value(s) for this meta field. This returns an array
    $term_meta = get_option( "taxonomy_$t_id" ); ?>
	
	<?php wp_enqueue_media(); ?>
		
    <tr class="form-field">
		<th scope="row" valign="top">
			<label for="term_meta[store_thumbnail]"><?php esc_html_e( 'Thumbnail', 'froday' ); ?></label>
		</th>
		<td>
			<div class="image-preview-wrapper">
				<img id="image-preview" src="<?php echo wp_get_attachment_url( $term_meta['store_thumbnail'] ); ?>" width="100">
			</div>
			<input id="upload_image_button" type="button" class="button" value="<?php esc_html_e( 'Upload image','froday' ); ?>" />
			<input type='hidden' name='term_meta[store_thumbnail]' id='image_attachment_id' value='<?php echo esc_attr( $term_meta['store_thumbnail'] ) ? esc_attr( $term_meta['store_thumbnail'] ) : ''; ?>'>
		</td>
    </tr>
<?php
}
add_action( 'store_edit_form_fields', 'froday_taxonomy_edit_meta_field');



/*************************************************
## Save extra taxonomy fields callback function.
*************************************************/ 

add_action( 'edited_category', 'froday_save_taxonomy_custom_meta', 10, 2 );
add_action( 'create_category', 'froday_save_taxonomy_custom_meta', 10, 2 );
 
function froday_save_taxonomy_custom_meta( $term_id ) {
    if ( isset( $_POST['term_meta'] ) ) {
        $t_id = $term_id;
        $term_meta = get_option( "taxonomy_$t_id" );
        $cat_keys = array_keys( $_POST['term_meta'] );
        foreach ( $cat_keys as $key ) {
            if ( isset ( $_POST['term_meta'][$key] ) ) {
                $term_meta[$key] = $_POST['term_meta'][$key];
            }
        }
        // Save the option array.
        update_option( "taxonomy_$t_id", $term_meta );
		update_option( 'media_selector_attachment_id', absint( $_POST[$term_meta] ) );

    }
}

// Add fields on custom taxonomies
add_action( 'create_store', 'froday_save_taxonomy_custom_meta');
add_action( 'edited_store', 'froday_save_taxonomy_custom_meta');


/*************************************************
## Save extra taxonomy fields callback function.
*************************************************/ 

add_action( 'admin_footer', 'froday_media_selector_print_scripts' );
function froday_media_selector_print_scripts() {

	$my_saved_attachment_post_id = get_option( 'media_selector_attachment_id', 0 );

	?><script type='text/javascript'>
jQuery.noConflict();
(function ($) {
  "use strict";
	$(document).ready(function () {
			// Uploading files

			$('#upload_image_button').on('click', function( event ){
				var file_frame;
				var wp_media_post_id = wp.media.model.settings.post.id; // Store the old id
				var set_to_post_id = <?php echo esc_attr($my_saved_attachment_post_id); ?>; // Set this
					
				event.preventDefault();
				// If the media frame already exists, reopen it.
				if ( file_frame ) {
					// Set the post ID to what we want
					file_frame.uploader.uploader.param( 'post_id', set_to_post_id );
					// Open frame
					file_frame.open();
					return;
				} else {
					// Set the wp.media post id so the uploader grabs the ID we want when initialised
					wp.media.model.settings.post.id = set_to_post_id;
				}
				// Create the media frame.
				file_frame = wp.media.frames.file_frame = wp.media({
					title: 'Select a image to upload',
					button: {
						text: 'Use this image',
					},
					multiple: false	// Set to true to allow multiple files to be selected
				});
				// When an image is selected, run a callback.
				file_frame.on( 'select', function() {
					// We set multiple to false so only get one image from the uploader
					var attachment = file_frame.state().get('selection').first().toJSON();
					// Do something with attachment.id and/or attachment.url here
					$( '#image-preview' ).attr( 'src', attachment.url ).css( 'width', 'auto' );
					$( '#image_attachment_id' ).val( attachment.id );
					// Restore the main post ID
					wp.media.model.settings.post.id = wp_media_post_id;
				});
					// Finally, open the modal
					file_frame.open();
			});
			// Restore the main ID when the add media button is pressed
			$( 'a.add_media' ).on( 'click', function() {
				wp.media.model.settings.post.id = wp_media_post_id;
			});
		});
})(jQuery);
	</script><?php
}


/*************************************************
## Get Store Thumbnail Meta
*************************************************/ 

function froday_store_thumbnail(){
	
	$terms = get_the_terms( get_the_ID(), 'store' );
    if($terms){                   
		foreach ( $terms as $term ) {
			$term_data = get_option('taxonomy_'.$term->term_id);
			if(isset($term_data['store_thumbnail'])){
				
			return '<a href="'.esc_url(get_term_link( $term )).'"><img src="'.wp_get_attachment_url( $term_data['store_thumbnail'] ).'" alt="'.$term->name.'"/></a>';

			}
		}
	}
}


/*************************************************
## Get Store Title
*************************************************/ 

function froday_store_title(){
	
	$terms = get_the_terms( get_the_ID(), 'store' );
    if($terms){                   
		foreach ( $terms as $term ) {
			$term_data = get_option('taxonomy_'.$term->term_id);
			if(isset($term_data['store_thumbnail'])){
				
			return '<a href="'.esc_url(get_term_link( $term )).'">'.esc_html($term->name).'</a>';

			}
		}
	}
}

/*************************************************
## Get Store Description
*************************************************/ 

function froday_store_description(){
	
	$terms = get_the_terms( get_the_ID(), 'store' );
    if($terms){                   
		foreach ( $terms as $term ) {
			return froday_sanitize_data($term->description);
		}
	}
}

/*************************************************
## Get Store Term Link
*************************************************/ 

function froday_store_link(){
	
	$terms = get_the_terms( get_the_ID(), 'store' );
    if($terms){                   
		foreach ( $terms as $term ) {
			return esc_url(get_term_link( $term ));
		}
	}
}


/*************************************************
## Get Store Shop_Coupon Count
*************************************************/ 

function froday_store_count($post_type){
	
	$terms = get_the_terms( get_the_ID(), 'store');
	if($terms){
	foreach($terms as $term) {
		global $post;
		$args = array(
			'post_type' => $post_type,
			'posts_per_page'   => 50,
			'tax_query' => array(
				array(
					'taxonomy' => 'store',
					'field' => 'term_id',
					'terms' => $term->term_id,
				)
			)
		);
		$count = 0;
		$stores = get_posts( $args );
		if ( $stores ) {
			foreach ( $stores as $post ) {
				$count++;
			}
			echo esc_html($count);
			wp_reset_postdata();
		} else {
			echo esc_html('0');
		}
	}
	}
}


/*************************************************
## Get Store Rating
*************************************************/ 

function froday_store_rating(){
	
	$terms = get_the_terms( get_the_ID(), 'store');
	if($terms){
	foreach($terms as $term) {
		global $post;
		global $product;
		$args = array(
			'post_type' => 'product', 
			'tax_query' => array(
				array(
					'taxonomy' => 'store',
					'field' => 'term_id',
					'terms' => $term->term_id,
				)
			)
		);

		$features_comment_count = 0;
		$average = 0;
		$stores = get_posts( $args );
		$count = 0;
		if ( $stores ) {
			foreach ( $stores as $post ) {
				$product = new WC_Product(get_the_ID());
				
				$features_comment_count += get_comments_number();
				$average += $product->get_average_rating();
								
				$count++;
			}
			
		       $average_width = (($average / $count) * 20);
				echo '<div class="star-rating rating-stars">
						<span style="width:'.$average_width.'%"></span>
					  </div>
					  <span class="rating-reviews">
						( <span class="rating-count">'.$features_comment_count.'</span> '; echo esc_html__('rates','klb-shortcode').' )
					  </span>';	

			wp_reset_postdata();
		}
	}
	}
}
